@@ -258,21 +258,12 @@ pub struct EntryVerificationState {
     device_verification_data: DeviceVerificationData,
 }
 
-#[derive(Clone)]
+#[derive(Default, Clone)]
 pub struct VerifyRecyclers {
     hash_recycler: Recycler<PinnedVec<Hash>>,
     tick_count_recycler: Recycler<PinnedVec<u64>>,
 }
 
-impl Default for VerifyRecyclers {
-    fn default() -> Self {
-        Self {
-            hash_recycler: Recycler::new_without_limit("hash_recycler_shrink_stats"),
-            tick_count_recycler: Recycler::new_without_limit("tick_count_recycler_shrink_stats"),
-        }
-    }
-}
-
 #[derive(PartialEq, Clone, Copy, Debug)]
 pub enum EntryVerificationStatus {
     Failure,
@@ -304,6 +295,7 @@ impl EntryVerificationState {
                     thread_pool.borrow().install(|| {
                         hashes
                             .into_par_iter()
+                            .cloned()
                             .zip(verification_state.verifications.take().unwrap())
                             .all(|(hash, (action, expected))| {
                                 let actual = match action {
@@ -367,7 +359,7 @@ pub trait EntrySlice {
     fn verify_and_hash_transactions(
         &self,
         skip_verification: bool,
-        libsecp256k1_0_5_upgrade_enabled: bool,
+        secp256k1_program_enabled: bool,
     ) -> Option<Vec<EntryType<'_>>>;
 }
 
@@ -522,7 +514,7 @@ impl EntrySlice for [Entry] {
     fn verify_and_hash_transactions<'a>(
         &'a self,
         skip_verification: bool,
-        libsecp256k1_0_5_upgrade_enabled: bool,
+        secp256k1_program_enabled: bool,
     ) -> Option<Vec<EntryType<'a>>> {
         let verify_and_hash = |tx: &'a Transaction| -> Option<HashedTransaction<'a>> {
             let message_hash = if !skip_verification {
@@ -530,8 +522,10 @@ impl EntrySlice for [Entry] {
                 if size > PACKET_DATA_SIZE as u64 {
                     return None;
                 }
-                tx.verify_precompiles(libsecp256k1_0_5_upgrade_enabled)
-                    .ok()?;
+                if secp256k1_program_enabled {
+                    // Verify tx precompiles if secp256k1 program is enabled.
+                    tx.verify_precompiles().ok()?;
+                }
                 tx.verify_and_hash_message().ok()?
             } else {
                 tx.message().hash()
@@ -587,12 +581,14 @@ impl EntrySlice for [Entry] {
             .take(self.len())
             .collect();
 
-        let mut hashes_pinned = recyclers.hash_recycler.allocate().unwrap();
+        let mut hashes_pinned = recyclers.hash_recycler.allocate("poh_verify_hash");
         hashes_pinned.set_pinnable();
         hashes_pinned.resize(hashes.len(), Hash::default());
         hashes_pinned.copy_from_slice(&hashes);
 
-        let mut num_hashes_vec = recyclers.tick_count_recycler.allocate().unwrap();
+        let mut num_hashes_vec = recyclers
+            .tick_count_recycler
+            .allocate("poh_verify_num_hashes");
         num_hashes_vec.reserve_and_pin(cmp::max(1, self.len()));
         for entry in self {
             num_hashes_vec.push(entry.num_hashes.saturating_sub(1));
@@ -872,17 +868,14 @@ mod tests {
         solana_logger::setup();
         let zero = Hash::default();
         let one = hash(&zero.as_ref());
-        assert_eq!(vec![][..].verify(&zero), true); // base case
-        assert_eq!(vec![Entry::new_tick(0, &zero)][..].verify(&zero), true); // singleton case 1
-        assert_eq!(vec![Entry::new_tick(0, &zero)][..].verify(&one), false); // singleton case 2, bad
-        assert_eq!(
-            vec![next_entry(&zero, 0, vec![]); 2][..].verify(&zero),
-            true
-        ); // inductive step
+        assert!(vec![][..].verify(&zero)); // base case
+        assert!(vec![Entry::new_tick(0, &zero)][..].verify(&zero)); // singleton case 1
+        assert!(!vec![Entry::new_tick(0, &zero)][..].verify(&one)); // singleton case 2, bad
+        assert!(vec![next_entry(&zero, 0, vec![]); 2][..].verify(&zero)); // inductive step
 
         let mut bad_ticks = vec![next_entry(&zero, 0, vec![]); 2];
         bad_ticks[1].hash = one;
-        assert_eq!(bad_ticks.verify(&zero), false); // inductive step, bad
+        assert!(!bad_ticks.verify(&zero)); // inductive step, bad
     }
 
     #[test]
@@ -891,18 +884,18 @@ mod tests {
         let zero = Hash::default();
         let one = hash(&zero.as_ref());
         let two = hash(&one.as_ref());
-        assert_eq!(vec![][..].verify(&one), true); // base case
-        assert_eq!(vec![Entry::new_tick(1, &two)][..].verify(&one), true); // singleton case 1
-        assert_eq!(vec![Entry::new_tick(1, &two)][..].verify(&two), false); // singleton case 2, bad
+        assert!(vec![][..].verify(&one)); // base case
+        assert!(vec![Entry::new_tick(1, &two)][..].verify(&one)); // singleton case 1
+        assert!(!vec![Entry::new_tick(1, &two)][..].verify(&two)); // singleton case 2, bad
 
         let mut ticks = vec![next_entry(&one, 1, vec![])];
         ticks.push(next_entry(&ticks.last().unwrap().hash, 1, vec![]));
-        assert_eq!(ticks.verify(&one), true); // inductive step
+        assert!(ticks.verify(&one)); // inductive step
 
         let mut bad_ticks = vec![next_entry(&one, 1, vec![])];
         bad_ticks.push(next_entry(&bad_ticks.last().unwrap().hash, 1, vec![]));
         bad_ticks[1].hash = one;
-        assert_eq!(bad_ticks.verify(&one), false); // inductive step, bad
+        assert!(!bad_ticks.verify(&one)); // inductive step, bad
     }
 
     #[test]
@@ -914,15 +907,9 @@ mod tests {
         let alice_pubkey = Keypair::new();
         let tx0 = create_sample_payment(&alice_pubkey, one);
         let tx1 = create_sample_timestamp(&alice_pubkey, one);
-        assert_eq!(vec![][..].verify(&one), true); // base case
-        assert_eq!(
-            vec![next_entry(&one, 1, vec![tx0.clone()])][..].verify(&one),
-            true
-        ); // singleton case 1
-        assert_eq!(
-            vec![next_entry(&one, 1, vec![tx0.clone()])][..].verify(&two),
-            false
-        ); // singleton case 2, bad
+        assert!(vec![][..].verify(&one)); // base case
+        assert!(vec![next_entry(&one, 1, vec![tx0.clone()])][..].verify(&one)); // singleton case 1
+        assert!(!vec![next_entry(&one, 1, vec![tx0.clone()])][..].verify(&two)); // singleton case 2, bad
 
         let mut ticks = vec![next_entry(&one, 1, vec![tx0.clone()])];
         ticks.push(next_entry(
@@ -930,12 +917,12 @@ mod tests {
             1,
             vec![tx1.clone()],
         ));
-        assert_eq!(ticks.verify(&one), true); // inductive step
+        assert!(ticks.verify(&one)); // inductive step
 
         let mut bad_ticks = vec![next_entry(&one, 1, vec![tx0])];
         bad_ticks.push(next_entry(&bad_ticks.last().unwrap().hash, 1, vec![tx1]));
         bad_ticks[1].hash = one;
-        assert_eq!(bad_ticks.verify(&one), false); // inductive step, bad
+        assert!(!bad_ticks.verify(&one)); // inductive step, bad
     }
 
     #[test]
